@@ -3,6 +3,7 @@ from __future__ import annotations
 import json
 from uuid import UUID
 
+import django
 import pytest
 from django.core.serializers.json import DjangoJSONEncoder
 from django.http import HttpResponse, StreamingHttpResponse
@@ -15,6 +16,7 @@ from django_htmx.http import (
     HttpResponseStopPolling,
     push_url,
     replace_url,
+    reselect,
     reswap,
     retarget,
     trigger_client_event,
@@ -37,6 +39,17 @@ class HttpResponseClientRedirectTests(SimpleTestCase):
         assert response["HX-Redirect"] == "https://example.com"
         assert "Location" not in response
 
+    @pytest.mark.skipif(
+        django.VERSION < (5, 2), reason="Django 5.2 introduced preserve_request"
+    )
+    def test_fail_preserve_request(self):
+        with pytest.raises(ValueError) as exinfo:
+            HttpResponseClientRedirect("https://example.com", preserve_request=True)
+        assert exinfo.value.args == (
+            "The 'preserve_request' argument is not supported for "
+            "HttpResponseClientRedirect.",
+        )
+
     def test_repr(self):
         response = HttpResponseClientRedirect("https://example.com")
 
@@ -147,6 +160,16 @@ class RetargetTests(SimpleTestCase):
         assert response["HX-Retarget"] == "#heading"
 
 
+class ReselectTests(SimpleTestCase):
+    def test_success(self):
+        response = HttpResponse()
+
+        response2 = reselect(response, "#list")
+
+        assert response2 is response
+        assert response["HX-Reselect"] == "#list"
+
+
 class TriggerClientEventTests(SimpleTestCase):
     def test_fail_bad_after_value(self):
         response = HttpResponse()
